@@ -46,6 +46,8 @@ namespace orc {
     WriterMetrics* metrics;
     bool useTightNumericVector;
     uint64_t outputBufferCapacity;
+    uint64_t memoryBlockSize;
+    bool alignBlockBoundToRowGroup;
 
     WriterOptionsPrivate() : fileVersion(FileVersion::v_0_12()) {  // default to Hive_0_12
       stripeSize = 64 * 1024 * 1024;                               // 64M
@@ -67,28 +69,30 @@ namespace orc {
       metrics = nullptr;
       useTightNumericVector = false;
       outputBufferCapacity = 1024 * 1024;
+      memoryBlockSize = 64 * 1024;  // 64K
+      alignBlockBoundToRowGroup = false;
     }
   };
 
   WriterOptions::WriterOptions()
-      : privateBits(std::unique_ptr<WriterOptionsPrivate>(new WriterOptionsPrivate())) {
+      : privateBits_(std::unique_ptr<WriterOptionsPrivate>(new WriterOptionsPrivate())) {
     // PASS
   }
 
   WriterOptions::WriterOptions(const WriterOptions& rhs)
-      : privateBits(std::unique_ptr<WriterOptionsPrivate>(
-            new WriterOptionsPrivate(*(rhs.privateBits.get())))) {
+      : privateBits_(std::unique_ptr<WriterOptionsPrivate>(
+            new WriterOptionsPrivate(*(rhs.privateBits_.get())))) {
     // PASS
   }
 
   WriterOptions::WriterOptions(WriterOptions& rhs) {
     // swap privateBits with rhs
-    privateBits.swap(rhs.privateBits);
+    privateBits_.swap(rhs.privateBits_);
   }
 
   WriterOptions& WriterOptions::operator=(const WriterOptions& rhs) {
     if (this != &rhs) {
-      privateBits.reset(new WriterOptionsPrivate(*(rhs.privateBits.get())));
+      privateBits_.reset(new WriterOptionsPrivate(*(rhs.privateBits_.get())));
     }
     return *this;
   }
@@ -97,7 +101,7 @@ namespace orc {
     // PASS
   }
   RleVersion WriterOptions::getRleVersion() const {
-    if (privateBits->fileVersion == FileVersion::v_0_11()) {
+    if (privateBits_->fileVersion == FileVersion::v_0_11()) {
       return RleVersion_1;
     }
 
@@ -105,186 +109,204 @@ namespace orc {
   }
 
   WriterOptions& WriterOptions::setStripeSize(uint64_t size) {
-    privateBits->stripeSize = size;
+    privateBits_->stripeSize = size;
     return *this;
   }
 
   uint64_t WriterOptions::getStripeSize() const {
-    return privateBits->stripeSize;
+    return privateBits_->stripeSize;
   }
 
   WriterOptions& WriterOptions::setCompressionBlockSize(uint64_t size) {
     if (size >= (1 << 23)) {
       throw std::invalid_argument("Compression block size cannot be greater or equal than 8M");
     }
-    privateBits->compressionBlockSize = size;
+    privateBits_->compressionBlockSize = size;
     return *this;
   }
 
   uint64_t WriterOptions::getCompressionBlockSize() const {
-    return privateBits->compressionBlockSize;
+    return privateBits_->compressionBlockSize;
   }
 
   WriterOptions& WriterOptions::setRowIndexStride(uint64_t stride) {
-    privateBits->rowIndexStride = stride;
-    privateBits->enableIndex = (stride != 0);
+    privateBits_->rowIndexStride = stride;
+    privateBits_->enableIndex = (stride != 0);
     return *this;
   }
 
   uint64_t WriterOptions::getRowIndexStride() const {
-    return privateBits->rowIndexStride;
+    return privateBits_->rowIndexStride;
   }
 
   WriterOptions& WriterOptions::setDictionaryKeySizeThreshold(double val) {
-    privateBits->dictionaryKeySizeThreshold = val;
+    privateBits_->dictionaryKeySizeThreshold = val;
     return *this;
   }
 
   double WriterOptions::getDictionaryKeySizeThreshold() const {
-    return privateBits->dictionaryKeySizeThreshold;
+    return privateBits_->dictionaryKeySizeThreshold;
   }
 
   WriterOptions& WriterOptions::setFileVersion(const FileVersion& version) {
     // Only Hive_0_11 and Hive_0_12 version are supported currently
     if (version.getMajor() == 0 && (version.getMinor() == 11 || version.getMinor() == 12)) {
-      privateBits->fileVersion = version;
+      privateBits_->fileVersion = version;
       return *this;
     }
     if (version == FileVersion::UNSTABLE_PRE_2_0()) {
-      *privateBits->errorStream << "Warning: ORC files written in "
-                                << FileVersion::UNSTABLE_PRE_2_0().toString()
-                                << " will not be readable by other versions of the software."
-                                << " It is only for developer testing.\n";
-      privateBits->fileVersion = version;
+      *privateBits_->errorStream << "Warning: ORC files written in "
+                                 << FileVersion::UNSTABLE_PRE_2_0().toString()
+                                 << " will not be readable by other versions of the software."
+                                 << " It is only for developer testing.\n";
+      privateBits_->fileVersion = version;
       return *this;
     }
     throw std::logic_error("Unsupported file version specified.");
   }
 
   FileVersion WriterOptions::getFileVersion() const {
-    return privateBits->fileVersion;
+    return privateBits_->fileVersion;
   }
 
   WriterOptions& WriterOptions::setCompression(CompressionKind comp) {
-    privateBits->compression = comp;
+    privateBits_->compression = comp;
     return *this;
   }
 
   CompressionKind WriterOptions::getCompression() const {
-    return privateBits->compression;
+    return privateBits_->compression;
   }
 
   WriterOptions& WriterOptions::setCompressionStrategy(CompressionStrategy strategy) {
-    privateBits->compressionStrategy = strategy;
+    privateBits_->compressionStrategy = strategy;
     return *this;
   }
 
   CompressionStrategy WriterOptions::getCompressionStrategy() const {
-    return privateBits->compressionStrategy;
+    return privateBits_->compressionStrategy;
   }
 
   bool WriterOptions::getAlignedBitpacking() const {
-    return privateBits->compressionStrategy == CompressionStrategy ::CompressionStrategy_SPEED;
+    return privateBits_->compressionStrategy == CompressionStrategy ::CompressionStrategy_SPEED;
   }
 
   WriterOptions& WriterOptions::setPaddingTolerance(double tolerance) {
-    privateBits->paddingTolerance = tolerance;
+    privateBits_->paddingTolerance = tolerance;
     return *this;
   }
 
   double WriterOptions::getPaddingTolerance() const {
-    return privateBits->paddingTolerance;
+    return privateBits_->paddingTolerance;
   }
 
   WriterOptions& WriterOptions::setMemoryPool(MemoryPool* memoryPool) {
-    privateBits->memoryPool = memoryPool;
+    privateBits_->memoryPool = memoryPool;
     return *this;
   }
 
   MemoryPool* WriterOptions::getMemoryPool() const {
-    return privateBits->memoryPool;
+    return privateBits_->memoryPool;
   }
 
   WriterOptions& WriterOptions::setErrorStream(std::ostream& errStream) {
-    privateBits->errorStream = &errStream;
+    privateBits_->errorStream = &errStream;
     return *this;
   }
 
   std::ostream* WriterOptions::getErrorStream() const {
-    return privateBits->errorStream;
+    return privateBits_->errorStream;
   }
 
   bool WriterOptions::getEnableIndex() const {
-    return privateBits->enableIndex;
+    return privateBits_->enableIndex;
   }
 
   bool WriterOptions::getEnableDictionary() const {
-    return privateBits->dictionaryKeySizeThreshold > 0.0;
+    return privateBits_->dictionaryKeySizeThreshold > 0.0;
   }
 
   WriterOptions& WriterOptions::setColumnsUseBloomFilter(const std::set<uint64_t>& columns) {
-    privateBits->columnsUseBloomFilter = columns;
+    privateBits_->columnsUseBloomFilter = columns;
     return *this;
   }
 
   bool WriterOptions::isColumnUseBloomFilter(uint64_t column) const {
-    return privateBits->columnsUseBloomFilter.find(column) !=
-           privateBits->columnsUseBloomFilter.end();
+    return privateBits_->columnsUseBloomFilter.find(column) !=
+           privateBits_->columnsUseBloomFilter.end();
   }
 
   WriterOptions& WriterOptions::setBloomFilterFPP(double fpp) {
-    privateBits->bloomFilterFalsePositiveProb = fpp;
+    privateBits_->bloomFilterFalsePositiveProb = fpp;
     return *this;
   }
 
   double WriterOptions::getBloomFilterFPP() const {
-    return privateBits->bloomFilterFalsePositiveProb;
+    return privateBits_->bloomFilterFalsePositiveProb;
   }
 
   // delibrately not provide setter to write bloom filter version because
   // we only support UTF8 for now.
   BloomFilterVersion WriterOptions::getBloomFilterVersion() const {
-    return privateBits->bloomFilterVersion;
+    return privateBits_->bloomFilterVersion;
   }
 
   const Timezone& WriterOptions::getTimezone() const {
-    return getTimezoneByName(privateBits->timezone);
+    return getTimezoneByName(privateBits_->timezone);
   }
 
   const std::string& WriterOptions::getTimezoneName() const {
-    return privateBits->timezone;
+    return privateBits_->timezone;
   }
 
   WriterOptions& WriterOptions::setTimezoneName(const std::string& zone) {
-    privateBits->timezone = zone;
+    privateBits_->timezone = zone;
     return *this;
   }
 
   WriterMetrics* WriterOptions::getWriterMetrics() const {
-    return privateBits->metrics;
+    return privateBits_->metrics;
   }
 
   WriterOptions& WriterOptions::setWriterMetrics(WriterMetrics* metrics) {
-    privateBits->metrics = metrics;
+    privateBits_->metrics = metrics;
     return *this;
   }
 
   WriterOptions& WriterOptions::setUseTightNumericVector(bool useTightNumericVector) {
-    privateBits->useTightNumericVector = useTightNumericVector;
+    privateBits_->useTightNumericVector = useTightNumericVector;
     return *this;
   }
 
   bool WriterOptions::getUseTightNumericVector() const {
-    return privateBits->useTightNumericVector;
+    return privateBits_->useTightNumericVector;
   }
 
   WriterOptions& WriterOptions::setOutputBufferCapacity(uint64_t capacity) {
-    privateBits->outputBufferCapacity = capacity;
+    privateBits_->outputBufferCapacity = capacity;
     return *this;
   }
 
   uint64_t WriterOptions::getOutputBufferCapacity() const {
-    return privateBits->outputBufferCapacity;
+    return privateBits_->outputBufferCapacity;
+  }
+
+  WriterOptions& WriterOptions::setMemoryBlockSize(uint64_t capacity) {
+    privateBits_->memoryBlockSize = capacity;
+    return *this;
+  }
+
+  uint64_t WriterOptions::getMemoryBlockSize() const {
+    return privateBits_->memoryBlockSize;
+  }
+
+  WriterOptions& WriterOptions::setAlignBlockBoundToRowGroup(bool alignBlockBoundToRowGroup) {
+    privateBits_->alignBlockBoundToRowGroup = alignBlockBoundToRowGroup;
+    return *this;
+  }
+
+  bool WriterOptions::getAlignBlockBoundToRowGroup() const {
+    return privateBits_->alignBlockBoundToRowGroup;
   }
 
   Writer::~Writer() {
@@ -293,25 +315,25 @@ namespace orc {
 
   class WriterImpl : public Writer {
    private:
-    std::unique_ptr<ColumnWriter> columnWriter;
-    std::unique_ptr<BufferedOutputStream> compressionStream;
-    std::unique_ptr<BufferedOutputStream> bufferedStream;
-    std::unique_ptr<StreamsFactory> streamsFactory;
-    OutputStream* outStream;
-    WriterOptions options;
-    const Type& type;
-    uint64_t stripeRows, totalRows, indexRows;
-    uint64_t currentOffset;
-    proto::Footer fileFooter;
-    proto::PostScript postScript;
-    proto::StripeInformation stripeInfo;
-    proto::Metadata metadata;
+    std::unique_ptr<ColumnWriter> columnWriter_;
+    std::unique_ptr<BufferedOutputStream> compressionStream_;
+    std::unique_ptr<BufferedOutputStream> bufferedStream_;
+    std::unique_ptr<StreamsFactory> streamsFactory_;
+    OutputStream* outStream_;
+    WriterOptions options_;
+    const Type& type_;
+    uint64_t stripeRows_, totalRows_, indexRows_;
+    uint64_t currentOffset_;
+    proto::Footer fileFooter_;
+    proto::PostScript postScript_;
+    proto::StripeInformation stripeInfo_;
+    proto::Metadata metadata_;
 
     static const char* magicId;
     static const WriterId writerId;
-    bool useTightNumericVector;
-    int32_t stripesAtLastFlush;
-    uint64_t lastFlushOffset;
+    bool useTightNumericVector_;
+    int32_t stripesAtLastFlush_;
+    uint64_t lastFlushOffset_;
 
    public:
     WriterImpl(const Type& type, OutputStream* stream, const WriterOptions& options);
@@ -342,93 +364,101 @@ namespace orc {
   const WriterId WriterImpl::writerId = WriterId::ORC_CPP_WRITER;
 
   WriterImpl::WriterImpl(const Type& t, OutputStream* stream, const WriterOptions& opts)
-      : outStream(stream), options(opts), type(t) {
-    streamsFactory = createStreamsFactory(options, outStream);
-    columnWriter = buildWriter(type, *streamsFactory, options);
-    stripeRows = totalRows = indexRows = 0;
-    currentOffset = 0;
-    stripesAtLastFlush = 0;
-    lastFlushOffset = 0;
+      : outStream_(stream), options_(opts), type_(t) {
+    streamsFactory_ = createStreamsFactory(options_, outStream_);
+    columnWriter_ = buildWriter(type_, *streamsFactory_, options_);
+    stripeRows_ = totalRows_ = indexRows_ = 0;
+    currentOffset_ = 0;
+    stripesAtLastFlush_ = 0;
+    lastFlushOffset_ = 0;
 
-    useTightNumericVector = opts.getUseTightNumericVector();
+    useTightNumericVector_ = opts.getUseTightNumericVector();
+
+    if (options_.getCompressionBlockSize() % options_.getMemoryBlockSize() != 0) {
+      throw std::invalid_argument(
+          "Compression block size must be a multiple of memory block size.");
+    }
 
     // compression stream for stripe footer, file footer and metadata
-    compressionStream =
-        createCompressor(options.getCompression(), outStream, options.getCompressionStrategy(),
-                         options.getOutputBufferCapacity(), options.getCompressionBlockSize(),
-                         *options.getMemoryPool(), options.getWriterMetrics());
+    compressionStream_ = createCompressor(
+        options_.getCompression(), outStream_, options_.getCompressionStrategy(),
+        options_.getOutputBufferCapacity(), options_.getCompressionBlockSize(),
+        options_.getMemoryBlockSize(), *options_.getMemoryPool(), options_.getWriterMetrics());
 
     // uncompressed stream for post script
-    bufferedStream.reset(new BufferedOutputStream(*options.getMemoryPool(), outStream,
-                                                  1024,  // buffer capacity: 1024 bytes
-                                                  options.getCompressionBlockSize(),
-                                                  options.getWriterMetrics()));
+    bufferedStream_.reset(new BufferedOutputStream(*options_.getMemoryPool(), outStream_,
+                                                   1024,  // buffer capacity: 1024 bytes
+                                                   options_.getCompressionBlockSize(),
+                                                   options_.getWriterMetrics()));
 
     init();
   }
 
   std::unique_ptr<ColumnVectorBatch> WriterImpl::createRowBatch(uint64_t size) const {
-    return type.createRowBatch(size, *options.getMemoryPool(), false, useTightNumericVector);
+    return type_.createRowBatch(size, *options_.getMemoryPool(), false, useTightNumericVector_);
   }
 
   void WriterImpl::add(ColumnVectorBatch& rowsToAdd) {
-    if (options.getEnableIndex()) {
+    if (options_.getEnableIndex()) {
       uint64_t pos = 0;
       uint64_t chunkSize = 0;
-      uint64_t rowIndexStride = options.getRowIndexStride();
+      uint64_t rowIndexStride = options_.getRowIndexStride();
       while (pos < rowsToAdd.numElements) {
-        chunkSize = std::min(rowsToAdd.numElements - pos, rowIndexStride - indexRows);
-        columnWriter->add(rowsToAdd, pos, chunkSize, nullptr);
+        chunkSize = std::min(rowsToAdd.numElements - pos, rowIndexStride - indexRows_);
+        columnWriter_->add(rowsToAdd, pos, chunkSize, nullptr);
 
         pos += chunkSize;
-        indexRows += chunkSize;
-        stripeRows += chunkSize;
+        indexRows_ += chunkSize;
+        stripeRows_ += chunkSize;
 
-        if (indexRows >= rowIndexStride) {
-          columnWriter->createRowIndexEntry();
-          indexRows = 0;
+        if (indexRows_ >= rowIndexStride) {
+          if (options_.getAlignBlockBoundToRowGroup()) {
+            columnWriter_->finishStreams();
+          }
+          columnWriter_->createRowIndexEntry();
+          indexRows_ = 0;
         }
       }
     } else {
-      stripeRows += rowsToAdd.numElements;
-      columnWriter->add(rowsToAdd, 0, rowsToAdd.numElements, nullptr);
+      stripeRows_ += rowsToAdd.numElements;
+      columnWriter_->add(rowsToAdd, 0, rowsToAdd.numElements, nullptr);
     }
 
-    if (columnWriter->getEstimatedSize() >= options.getStripeSize()) {
+    if (columnWriter_->getEstimatedSize() >= options_.getStripeSize()) {
       writeStripe();
     }
   }
 
   void WriterImpl::close() {
-    if (stripeRows > 0) {
+    if (stripeRows_ > 0) {
       writeStripe();
     }
     writeMetadata();
     writeFileFooter();
     writePostscript();
-    outStream->close();
+    outStream_->close();
   }
 
   uint64_t WriterImpl::writeIntermediateFooter() {
-    if (stripeRows > 0) {
+    if (stripeRows_ > 0) {
       writeStripe();
     }
-    if (stripesAtLastFlush != fileFooter.stripes_size()) {
+    if (stripesAtLastFlush_ != fileFooter_.stripes_size()) {
       writeMetadata();
       writeFileFooter();
       writePostscript();
-      stripesAtLastFlush = fileFooter.stripes_size();
-      outStream->flush();
-      lastFlushOffset = outStream->getLength();
-      currentOffset = lastFlushOffset;
+      stripesAtLastFlush_ = fileFooter_.stripes_size();
+      outStream_->flush();
+      lastFlushOffset_ = outStream_->getLength();
+      currentOffset_ = lastFlushOffset_;
       // init stripe now that we adjusted the currentOffset
       initStripe();
     }
-    return lastFlushOffset;
+    return lastFlushOffset_;
   }
 
   void WriterImpl::addUserMetadata(const std::string& name, const std::string& value) {
-    proto::UserMetadataItem* userMetadataItem = fileFooter.add_metadata();
+    proto::UserMetadataItem* userMetadataItem = fileFooter_.add_metadata();
     userMetadataItem->set_name(name);
     userMetadataItem->set_value(value);
   }
@@ -437,65 +467,65 @@ namespace orc {
     // Write file header
     const static size_t magicIdLength = strlen(WriterImpl::magicId);
     {
-      SCOPED_STOPWATCH(options.getWriterMetrics(), IOBlockingLatencyUs, IOCount);
-      outStream->write(WriterImpl::magicId, magicIdLength);
+      SCOPED_STOPWATCH(options_.getWriterMetrics(), IOBlockingLatencyUs, IOCount);
+      outStream_->write(WriterImpl::magicId, magicIdLength);
     }
-    currentOffset += magicIdLength;
+    currentOffset_ += magicIdLength;
 
     // Initialize file footer
-    fileFooter.set_header_length(currentOffset);
-    fileFooter.set_content_length(0);
-    fileFooter.set_number_of_rows(0);
-    fileFooter.set_row_index_stride(static_cast<uint32_t>(options.getRowIndexStride()));
-    fileFooter.set_writer(writerId);
-    fileFooter.set_software_version(ORC_VERSION);
+    fileFooter_.set_header_length(currentOffset_);
+    fileFooter_.set_content_length(0);
+    fileFooter_.set_number_of_rows(0);
+    fileFooter_.set_row_index_stride(static_cast<uint32_t>(options_.getRowIndexStride()));
+    fileFooter_.set_writer(writerId);
+    fileFooter_.set_software_version(ORC_VERSION);
 
     uint32_t index = 0;
-    buildFooterType(type, fileFooter, index);
+    buildFooterType(type_, fileFooter_, index);
 
     // Initialize post script
-    postScript.set_footer_length(0);
-    postScript.set_compression(WriterImpl::convertCompressionKind(options.getCompression()));
-    postScript.set_compression_block_size(options.getCompressionBlockSize());
+    postScript_.set_footer_length(0);
+    postScript_.set_compression(WriterImpl::convertCompressionKind(options_.getCompression()));
+    postScript_.set_compression_block_size(options_.getCompressionBlockSize());
 
-    postScript.add_version(options.getFileVersion().getMajor());
-    postScript.add_version(options.getFileVersion().getMinor());
+    postScript_.add_version(options_.getFileVersion().getMajor());
+    postScript_.add_version(options_.getFileVersion().getMinor());
 
-    postScript.set_writer_version(WriterVersion_ORC_135);
-    postScript.set_magic("ORC");
+    postScript_.set_writer_version(WriterVersion_ORC_135);
+    postScript_.set_magic("ORC");
 
     // Initialize first stripe
     initStripe();
   }
 
   void WriterImpl::initStripe() {
-    stripeInfo.set_offset(currentOffset);
-    stripeInfo.set_index_length(0);
-    stripeInfo.set_data_length(0);
-    stripeInfo.set_footer_length(0);
-    stripeInfo.set_number_of_rows(0);
+    stripeInfo_.set_offset(currentOffset_);
+    stripeInfo_.set_index_length(0);
+    stripeInfo_.set_data_length(0);
+    stripeInfo_.set_footer_length(0);
+    stripeInfo_.set_number_of_rows(0);
 
-    stripeRows = indexRows = 0;
+    stripeRows_ = indexRows_ = 0;
   }
 
   void WriterImpl::writeStripe() {
-    if (options.getEnableIndex() && indexRows != 0) {
-      columnWriter->createRowIndexEntry();
-      indexRows = 0;
+    if (options_.getEnableIndex() && indexRows_ != 0) {
+      columnWriter_->createRowIndexEntry();
+      indexRows_ = 0;
     } else {
-      columnWriter->mergeRowGroupStatsIntoStripeStats();
+      columnWriter_->mergeRowGroupStatsIntoStripeStats();
     }
 
     // dictionary should be written before any stream is flushed
-    columnWriter->writeDictionary();
+    columnWriter_->writeDictionary();
 
     std::vector<proto::Stream> streams;
     // write ROW_INDEX streams
-    if (options.getEnableIndex()) {
-      columnWriter->writeIndex(streams);
+    if (options_.getEnableIndex()) {
+      columnWriter_->writeIndex(streams);
     }
     // write streams like PRESENT, DATA, etc.
-    columnWriter->flush(streams);
+    columnWriter_->flush(streams);
 
     // generate and write stripe footer
     proto::StripeFooter stripeFooter;
@@ -504,28 +534,28 @@ namespace orc {
     }
 
     std::vector<proto::ColumnEncoding> encodings;
-    columnWriter->getColumnEncoding(encodings);
+    columnWriter_->getColumnEncoding(encodings);
 
     for (uint32_t i = 0; i < encodings.size(); ++i) {
       *stripeFooter.add_columns() = encodings[i];
     }
 
-    stripeFooter.set_writer_timezone(options.getTimezoneName());
+    stripeFooter.set_writer_timezone(options_.getTimezoneName());
 
     // add stripe statistics to metadata
-    proto::StripeStatistics* stripeStats = metadata.add_stripe_stats();
+    proto::StripeStatistics* stripeStats = metadata_.add_stripe_stats();
     std::vector<proto::ColumnStatistics> colStats;
-    columnWriter->getStripeStatistics(colStats);
+    columnWriter_->getStripeStatistics(colStats);
     for (uint32_t i = 0; i != colStats.size(); ++i) {
       *stripeStats->add_col_stats() = colStats[i];
     }
     // merge stripe stats into file stats and clear stripe stats
-    columnWriter->mergeStripeStatsIntoFileStats();
+    columnWriter_->mergeStripeStatsIntoFileStats();
 
-    if (!stripeFooter.SerializeToZeroCopyStream(compressionStream.get())) {
+    if (!stripeFooter.SerializeToZeroCopyStream(compressionStream_.get())) {
       throw std::logic_error("Failed to write stripe footer.");
     }
-    uint64_t footerLength = compressionStream->flush();
+    uint64_t footerLength = compressionStream_->flush();
 
     // calculate data length and index length
     uint64_t dataLength = 0;
@@ -540,53 +570,53 @@ namespace orc {
     }
 
     // update stripe info
-    stripeInfo.set_index_length(indexLength);
-    stripeInfo.set_data_length(dataLength);
-    stripeInfo.set_footer_length(footerLength);
-    stripeInfo.set_number_of_rows(stripeRows);
+    stripeInfo_.set_index_length(indexLength);
+    stripeInfo_.set_data_length(dataLength);
+    stripeInfo_.set_footer_length(footerLength);
+    stripeInfo_.set_number_of_rows(stripeRows_);
 
-    *fileFooter.add_stripes() = stripeInfo;
+    *fileFooter_.add_stripes() = stripeInfo_;
 
-    currentOffset = currentOffset + indexLength + dataLength + footerLength;
-    totalRows += stripeRows;
+    currentOffset_ = currentOffset_ + indexLength + dataLength + footerLength;
+    totalRows_ += stripeRows_;
 
-    columnWriter->reset();
+    columnWriter_->reset();
 
     initStripe();
   }
 
   void WriterImpl::writeMetadata() {
-    if (!metadata.SerializeToZeroCopyStream(compressionStream.get())) {
+    if (!metadata_.SerializeToZeroCopyStream(compressionStream_.get())) {
       throw std::logic_error("Failed to write metadata.");
     }
-    postScript.set_metadata_length(compressionStream.get()->flush());
+    postScript_.set_metadata_length(compressionStream_.get()->flush());
   }
 
   void WriterImpl::writeFileFooter() {
-    fileFooter.set_content_length(currentOffset - fileFooter.header_length());
-    fileFooter.set_number_of_rows(totalRows);
+    fileFooter_.set_content_length(currentOffset_ - fileFooter_.header_length());
+    fileFooter_.set_number_of_rows(totalRows_);
 
     // update file statistics
     std::vector<proto::ColumnStatistics> colStats;
-    columnWriter->getFileStatistics(colStats);
-    fileFooter.clear_statistics();
+    columnWriter_->getFileStatistics(colStats);
+    fileFooter_.clear_statistics();
     for (uint32_t i = 0; i != colStats.size(); ++i) {
-      *fileFooter.add_statistics() = colStats[i];
+      *fileFooter_.add_statistics() = colStats[i];
     }
 
-    if (!fileFooter.SerializeToZeroCopyStream(compressionStream.get())) {
+    if (!fileFooter_.SerializeToZeroCopyStream(compressionStream_.get())) {
       throw std::logic_error("Failed to write file footer.");
     }
-    postScript.set_footer_length(compressionStream->flush());
+    postScript_.set_footer_length(compressionStream_->flush());
   }
 
   void WriterImpl::writePostscript() {
-    if (!postScript.SerializeToZeroCopyStream(bufferedStream.get())) {
+    if (!postScript_.SerializeToZeroCopyStream(bufferedStream_.get())) {
       throw std::logic_error("Failed to write post script.");
     }
-    unsigned char psLength = static_cast<unsigned char>(bufferedStream->flush());
-    SCOPED_STOPWATCH(options.getWriterMetrics(), IOBlockingLatencyUs, IOCount);
-    outStream->write(&psLength, sizeof(unsigned char));
+    unsigned char psLength = static_cast<unsigned char>(bufferedStream_->flush());
+    SCOPED_STOPWATCH(options_.getWriterMetrics(), IOBlockingLatencyUs, IOCount);
+    outStream_->write(&psLength, sizeof(unsigned char));
   }
 
   void WriterImpl::buildFooterType(const Type& t, proto::Footer& footer, uint32_t& index) {
